@@ -2,4 +2,4 @@ mod autocomplete;
 mod indexable_keywords;
 mod search;
 mod search_and;
-mod string_keywords;
\ No newline at end of file
+pub(crate) mod string_keywords;
\ No newline at end of file
